@@ -26,7 +26,6 @@
 #include <stdlib.h>
 #include <glib/gi18n.h>
 #include <glib/gstdio.h>
-#include <glade/glade.h>
 #include <gtk/gtk.h>
 #include <gconf/gconf-client.h>
 #include "nautilus-sendto-plugin.h"
@@ -36,9 +35,15 @@
 #define NAUTILUS_SENDTO_LAST_COMPRESS	NAUTILUS_SENDTO_GCONF"/last_compress"
 #define NAUTILUS_SENDTO_STATUS_LABEL_TIMEOUT_SECONDS 10
 
-#define UNINSTALLED_PLUGINDIR "plugins/sylpheed-claws"
+#define UNINSTALLED_PLUGINDIR "plugins/removable-devices"
 #define UNINSTALLED_SOURCE "nautilus-sendto-command.c"
 
+enum {
+	COLUMN_ICON,
+	COLUMN_DESCRIPTION,
+	NUM_COLUMNS,
+};
+
 /* Options */
 static char **filenames = NULL;
 
@@ -403,7 +408,7 @@ set_contact_widgets (NS_ui *ui)
 	for (aux = plugin_list; aux; aux = aux->next){
 		p = (NstPlugin *) aux->data;
 		w = p->info->get_contacts_widget(p);
-		gtk_box_pack_end_defaults (GTK_BOX(ui->hbox_contacts_ws),w);
+		gtk_box_pack_end (GTK_BOX(ui->hbox_contacts_ws),w, TRUE, TRUE, 0);
 		gtk_widget_hide (GTK_WIDGET(w));
 		ui->contact_widgets = g_list_append (ui->contact_widgets, w);
 		if (GTK_IS_ENTRY (w)) {
@@ -418,7 +423,7 @@ set_model_for_options_combobox (NS_ui *ui)
 {
 	GdkPixbuf *pixbuf;
         GtkTreeIter iter;
-        GtkTreeStore *model;
+        GtkListStore *model;
 	GtkIconTheme *it;
 	GtkCellRenderer *renderer;
 	GList *aux;
@@ -429,7 +434,7 @@ set_model_for_options_combobox (NS_ui *ui)
 
 	it = gtk_icon_theme_get_default ();
 
-	model = gtk_tree_store_new (2, GDK_TYPE_PIXBUF, G_TYPE_STRING);
+	model = gtk_list_store_new (NUM_COLUMNS, GDK_TYPE_PIXBUF, G_TYPE_STRING);
 
 	last_used = gconf_client_get_string (gconf_client,
 			NAUTILUS_SENDTO_LAST_MEDIUM, NULL);
@@ -438,10 +443,10 @@ set_model_for_options_combobox (NS_ui *ui)
 		p = (NstPlugin *) aux->data;
 		pixbuf = gtk_icon_theme_load_icon (it, p->info->icon, 16, 
 						   GTK_ICON_LOOKUP_USE_BUILTIN, NULL);
-		gtk_tree_store_append (model, &iter, NULL);
-		gtk_tree_store_set (model, &iter,
-					0, pixbuf,
-					1, _(p->info->description),
+		gtk_list_store_append (model, &iter);
+		gtk_list_store_set (model, &iter,
+					COLUMN_ICON, pixbuf,
+					COLUMN_DESCRIPTION, _(p->info->description),
 					-1);
 		if (last_used != NULL && !strcmp(last_used, p->info->id)) {
 			option = i;
@@ -459,15 +464,16 @@ set_model_for_options_combobox (NS_ui *ui)
                                     FALSE);
         gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (ui->options_combobox), 
 					renderer,
-                                        "pixbuf", 0,
+                                        "pixbuf", COLUMN_ICON,
                                         NULL);		
         renderer = gtk_cell_renderer_text_new ();
+        g_object_set (G_OBJECT (renderer), "ellipsize", PANGO_ELLIPSIZE_END, NULL);
         gtk_cell_layout_pack_start (GTK_CELL_LAYOUT (ui->options_combobox),
                                     renderer,
                                     TRUE);
         gtk_cell_layout_set_attributes (GTK_CELL_LAYOUT (ui->options_combobox), 
 					renderer,
-                                        "text", 1,
+                                        "text", COLUMN_DESCRIPTION,
                                         NULL);
 
 	g_signal_connect (G_OBJECT (ui->options_combobox), "changed",
@@ -499,27 +505,32 @@ pack_entry_changed_cb (GObject *object, GParamSpec *spec, NS_ui *ui)
 static void
 nautilus_sendto_create_ui (void)
 {
-	GladeXML *app;	
+	GtkBuilder *app;	
+	GError* error = NULL;
 	NS_ui *ui;
 	gboolean one_file = FALSE;
 	gboolean supports_dirs;
 
-	app = glade_xml_new (GLADEDIR "/" "nautilus-sendto.glade", NULL, NULL);
+	app = gtk_builder_new ();
+	if (!gtk_builder_add_from_file (app, UIDIR "/" "nautilus-sendto.ui", &error))	{
+		g_warning ("Couldn't load builder file: %s", error->message);
+		g_error_free (error);
+	}
 
 	ui = g_new0 (NS_ui, 1);
 
-	ui->hbox_contacts_ws = glade_xml_get_widget (app, "hbox_contacts_widgets");
-	ui->send_to_label = glade_xml_get_widget (app, "send_to_label");
-	ui->options_combobox = glade_xml_get_widget (app, "options_combobox");
-	ui->dialog = glade_xml_get_widget (app, "nautilus_sendto_dialog");
-	ui->cancel_button = glade_xml_get_widget (app, "cancel_button");
-	ui->send_button = glade_xml_get_widget (app, "send_button");
-	ui->pack_combobox = glade_xml_get_widget (app, "pack_combobox");	
-	ui->pack_entry = glade_xml_get_widget (app, "pack_entry");
-	ui->pack_checkbutton = glade_xml_get_widget (app, "pack_checkbutton");
-	ui->status_box = glade_xml_get_widget (app, "status_box");
-	ui->status_label = glade_xml_get_widget (app, "status_label");
-	ui->status_image = glade_xml_get_widget (app, "status_image");
+	ui->hbox_contacts_ws = GTK_WIDGET (gtk_builder_get_object (app, "hbox_contacts_widgets"));
+	ui->send_to_label = GTK_WIDGET (gtk_builder_get_object (app, "send_to_label"));
+	ui->options_combobox = GTK_WIDGET (gtk_builder_get_object (app, "options_combobox"));
+	ui->dialog = GTK_WIDGET (gtk_builder_get_object (app, "nautilus_sendto_dialog"));
+	ui->cancel_button = GTK_WIDGET (gtk_builder_get_object (app, "cancel_button"));
+	ui->send_button = GTK_WIDGET (gtk_builder_get_object (app, "send_button"));
+	ui->pack_combobox = GTK_WIDGET (gtk_builder_get_object (app, "pack_combobox"));	
+	ui->pack_entry = GTK_WIDGET (gtk_builder_get_object (app, "pack_entry"));
+	ui->pack_checkbutton = GTK_WIDGET (gtk_builder_get_object (app, "pack_checkbutton"));
+	ui->status_box = GTK_WIDGET (gtk_builder_get_object (app, "status_box"));
+	ui->status_label = GTK_WIDGET (gtk_builder_get_object (app, "status_label"));
+	ui->status_image = GTK_WIDGET (gtk_builder_get_object (app, "status_image"));
 
  	gtk_combo_box_set_active (GTK_COMBO_BOX(ui->pack_combobox), 
  		gconf_client_get_int(gconf_client, 
